@@ -51,19 +51,7 @@ test_that('extras', {
     PLCI <- PLCI.mirt(mirt(Science, 1, verbose=FALSE), parnum=c(1,2))
     expect_equal(c(PLCI$lower_2.5, PLCI$upper_97.5), c(0.7008617, 4.0112247, 1.4530232, 5.9667792),
                   tolerance=1e-3)
-    DIFF <- suppressMessages(DIF(model1a, which.par='d', items2test = c(1,3)))
-    expect_is(DIFF, 'list')
-    expect_equal(DIFF[[1L]][2,'logLik'], -12509.81, tolerance = 1e-3)
-    DIFF2 <- suppressMessages(DIF(model2, which.par=c('a1', 'd'), items2test = c(1,3), scheme='drop'))
-    expect_is(DIFF2, 'list')
-    expect_equal(DIFF2[[1L]][,'logLik'], c(-12533.94, -12524.50), tolerance = 1e-3)
 
-    WALD <- suppressMessages(DIF(model1a, which.par='d', items2test = 1:3, Wald=TRUE))
-    expect_is(WALD, 'list')
-    expect_equal(WALD[[1]]$W[1], 1.532718, tolerance = 1e-3)
-    expect_equal(WALD[[1]]$p[1], 0.2157049, tolerance = 1e-3)
-    WALD2 <- suppressMessages(DIF(model1a, which.par=c('a1', 'd'), Wald=TRUE, p.adjust = 'fdr'))
-    expect_equal(as.numeric(WALD2$adj_pvals), c(0.02473307,0.01580279,0.1261503,0.4299811,0.4672727,0.4565218,0.05971613,0.5671398,0.4299811,0.4565218), tolerance = 1e-3)
     extr.2 <- extract.item(mod1, 2)
     Theta <- matrix(seq(-6,6, length.out=200))
     expected <- expected.item(extr.2, Theta)
